Name:          mybatis
Version:       3.2.2
Release:       3%{?dist}
Summary:       SQL Mapping Framework for Java
Group:         Development/Libraries
License:       ASL 2.0
# http://code.google.com/p/mybatis/
URL:           http://www.mybatis.org/
# git clone git://github.com/mybatis/mybatis-3.git mybatis-3.2.2
# (cd mybatis-3.2.2/ && git archive --format=tar --prefix=mybatis-3.2.2/ mybatis-3.2.2 | xz > ../mybatis-3.2.2-src-git.tar.xz)
Source0:       https://github.com/mybatis/mybatis-3/archive/%{name}-%{version}.tar.gz
# thanks to jhernand
# replace ognl ognl with apache-commons-ognl
Patch0:        %{name}-%{version}-commons-ognl.patch

BuildRequires: java-devel
BuildRequires: mybatis-parent

BuildRequires: apache-commons-logging
BuildRequires: apache-commons-ognl
BuildRequires: cglib
BuildRequires: javassist
BuildRequires: log4j
BuildRequires: slf4j


BuildRequires: maven-local
BuildRequires: maven-enforcer-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-bundle
BuildRequires: maven-plugin-cobertura
BuildRequires: maven-resources-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-surefire-provider-junit4

%if %{?fedora} > 18
BuildRequires: geronimo-parent-poms
%endif

# test deps
BuildRequires: junit
BuildRequires: mvn(commons-dbcp:commons-dbcp)
BuildRequires: mvn(org.apache.geronimo.specs:geronimo-jta_1.1_spec)
BuildRequires: mvn(org.apache.derby:derby)
# unavailable
%if 0
BuildRequires: mvn(org.hsqldb:hsqldb) >= 2.2.9
%else
BuildRequires: mvn(hsqldb:hsqldb)
%endif
BuildRequires: mvn(org.mockito:mockito-core)
BuildRequires: mvn(postgresql:postgresql)
BuildRequires: mvn(org.apache.velocity:velocity) >= 1.7


Requires:      apache-commons-logging
Requires:      apache-commons-ognl
Requires:      cglib
Requires:      javassist
Requires:      log4j
Requires:      slf4j

Requires:      java
BuildArch:     noarch

%description
The MyBatis data mapper framework makes it easier
to use a relational database with object-oriented
applications. MyBatis couples objects with stored
procedures or SQL statements using a XML descriptor
or annotations. Simplicity is the biggest advantage
of the MyBatis data mapper over object relational
mapping tools.

To use the MyBatis data mapper, you rely on your
own objects, XML, and SQL. There is little to
learn that you don't already know. With the
MyBatis data mapper, you have the full power of
both SQL and stored procedures at your fingertips. 

The MyBatis project is developed and maintained by
a team that includes the original creators of the
"iBATIS" data mapper. The Apache project was retired
and continued here.

%package javadoc
Group:         Documentation
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-3-%{name}-%{version}

%patch0 -p1
%pom_remove_plugin :maven-pdf-plugin
%pom_remove_plugin :jarjar-maven-plugin

%pom_remove_dep javax.transaction:transaction-api
%pom_add_dep org.apache.geronimo.specs:geronimo-jta_1.1_spec::test

# unavalable test deps hsqldb >= 2.2.9
# adapt for hsqldb 1.x
%pom_remove_dep org.hsqldb:hsqldb
%pom_add_dep hsqldb:hsqldb::test
#rm -r src/test/java/org/apache/ibatis/jdbc/PooledDataSourceTest.java
sed -i 's/JDBCConnection/jdbcConnection/' src/test/java/org/apache/ibatis/jdbc/PooledDataSourceTest.java
sed -i 's/(JDBCConnection)/(jdbcConnection)/' src/test/java/org/apache/ibatis/jdbc/PooledDataSourceTest.java
# These tests fails for various reasons
rm -r src/test/java/org/apache/ibatis/submitted/complex_type/ComplexTypeTest.java \
 src/test/java/org/apache/ibatis/submitted/awful_table/AwfulTableTest.java \
 src/test/java/org/apache/ibatis/submitted/sptests/SPTest.java \
 src/test/java/org/apache/ibatis/submitted/dynsql/DynSqlTest.java \
 src/test/java/org/apache/ibatis/submitted/selectkey/SelectKeyTest.java \
 src/test/java/org/apache/ibatis/submitted/blobtest/BlobTest.java \
 src/test/java/org/apache/ibatis/submitted/multipleiterates/MultipleIteratesTest.java \
 src/test/java/org/apache/ibatis/submitted/foreach_map/ForEachMapTest.java \
 src/test/java/org/apache/ibatis/submitted/batch_keys/BatchKeysTest.java

sed -i 's/\r//' LICENSE NOTICE

# original osgi.import contains !ognl,...
%pom_xpath_remove "pom:properties/pom:osgi.import"
%pom_xpath_inject "pom:properties" '
 <osgi.import>!org.apache.commons.ognl,net.sf.cglib.proxy;resolution:=optional,javassist.util.proxy;resolution:=optional,org.apache.commons.logging;resolution:=optional,org.apache.log4j;resolution:=optional,org.slf4j;resolution:=optional,*</osgi.import>'

%build

mvn-rpmbuild -Dproject.build.sourceEncoding=UTF-8 package javadoc:aggregate
 
%install

mkdir -p %{buildroot}%{_javadir}
install -m 644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

mkdir -p %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}

%files
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%doc LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE NOTICE

%changelog
* Sat May 11 2013 gil cattaneo <puntogil@libero.it> 3.2.2-3
- rebuilt with mybatis-parent

* Sun Apr 21 2013 gil cattaneo <puntogil@libero.it> 3.2.2-2
- rebuilt with mybatis-parent
- run test suite with hsqldb 1.x

* Sat Apr 20 2013 gil cattaneo <puntogil@libero.it> 3.2.2-1
- update to 3.2.2

* Fri Apr 20 2012 gil cattaneo <puntogil@libero.it> 3.1.1-1
- initial rpm